==> fillets-ng-data_0.8.0.orig.tar.gz: fillets-ng-data-0.8.0/script/engine/dialogs_bg.lua <==
dialogId("mot-m-info", "font_small", "I think we can gain some information about the interstellar propulsion here.")
dialogStr("Май тук ще намерим информация за междузвездната тяга.")

dialogId("mot-v-konvencni", "font_big", "This looks more like conventional propulsion for the landing craft.")
dialogStr("Това прилича на конвенционална тяга за приземяване.")

dialogId("mot-m-tak", "font_small", "So. We found the drive. We have achieved one of the objectives of our mission.")
dialogStr("Е, намерихме двигателя. Изпълнихме една от целите на мисията.")

dialogId("mot-v-zavery", "font_big", "Don’t be so hasty. We haven’t searched the whole wreck yet.")
dialogStr("Не прибързвай. Още не сме претърсили всички останки.")

dialogId("mot-m-akce0", "font_small", "I am sorry that none of these technical marvels around us work.")
dialogStr("Съжалявам, че никое от тези технически чудеса около нас не работи.")

dialogId("mot-m-akce1", "font_small", "I’d like to see some of these extraterrestrial gizmos in action.")
dialogStr("Бих искала да видя някоя от тези извънземни джаджи в действие.")

dialogId("mot-m-akce2", "font_small", "I wonder if this motor could work under water.")
dialogStr("Чудя се дали този мотор може да работи под вода?")

dialogId("mot-v-funkce0", "font_big", "Maybe it’s better for us if it doesn’t work.")
dialogStr("За нас може би е по-добре ако не работи.")

dialogId("mot-v-funkce1", "font_big", "I am rather glad we cannot turn anything on here.")
dialogStr("Аз пък се радвам, че не можем да включим нищо.")

dialogId("mot-v-funkce2", "font_big", "We should be happy that we could not switch anything on yet.")
dialogStr("Би трябвало да сме доволни, че все още не можем да включим нищо.")

dialogId("mot-v-klic", "font_big", "Careful with that wrench.")
dialogStr("Внимавай с този гаечен ключ.")

dialogId("mot-m-ublizit", "font_small", "I can’t harm anything here.")
dialogStr("Едва ли ще повредя нищо.")

dialogId("mot-m-zvuky0", "font_small", "What have you done? Turn off that roar!")
dialogStr("Какво направи? Изключи този рев!")

dialogId("mot-m-zvuky1", "font_small", "This is terrible! Turn it off before it’s too late!")
dialogStr("Това е ужасно! Изключи го преди да е станало късно!")

dialogId("mot-v-nemuzu0", "font_big", "I can’t! I can’t take it out!")
dialogStr("Не мога! Не мога да го извадя!")

dialogId("mot-v-nemuzu1", "font_big", "I don’t know how! I can’t take it out!")
dialogStr("Не знам как! Не мога да го извадя!")

dialogId("mot-m-mayday", "font_small", "Mayday! Mayday!")
dialogStr("Помощ! Помощ!")

dialogId("mot-v-konecne0", "font_big", "Finally.")
dialogStr("Най-сетне.")

dialogId("mot-v-konecne1", "font_big", "What a relief.")
dialogStr("Какво облекчение.")

dialogId("mot-v-zvuky0", "font_big", "What are you doing? Where are we going?")
dialogStr("Какво правиш? Къде отиваш?")

dialogId("mot-v-zvuky1", "font_big", "What have you activated? Where is it taking us?")
dialogStr("Какво си активирала? Къде ни води?")

dialogId("mot-m-nemuzu0", "font_small", "How can I turn it off?!")
dialogStr("Как да го изключа?!")

dialogId("mot-m-nemuzu1", "font_small", "I can’t turn it off!")
dialogStr("Не мога да го изключа!")

dialogId("mot-m-konecne0", "font_small", "Thanks.")
dialogStr("Благодаря.")

dialogId("mot-m-konecne1", "font_small", "Finally.")
dialogStr("Най-сетне.")

dialogId("mot-v-znovu0", "font_big", "I am only afraid we’ll have to turn it on again.")
dialogStr("Безпокоя се само, че ще се наложи пак до го включим.")

dialogId("mot-x-motor", "", "")
dialogStr("")

==> fillets-ng-data_1.0.1.orig.tar.gz: fillets-ng-data-1.0.1/script/engine/dialogs_bg.lua <==
dialogId("mot-m-info", "font_small", "I think we can gain some information about the interstellar propulsion here.")
dialogStr("Май тук ще намерим информация за междузвездната тяга.")

dialogId("mot-v-konvencni", "font_big", "This looks more like conventional propulsion for the landing craft.")
dialogStr("Това прилича на конвенционален двигател за приземяване.")

dialogId("mot-m-tak", "font_small", "So. We found the drive. We have achieved one of the objectives of our mission.")
dialogStr("Е, намерихме двигателя. Изпълнихме една от целите на мисията.")

dialogId("mot-v-zavery", "font_big", "Don’t be so hasty. We haven’t searched the whole wreck yet.")
dialogStr("Не прибързвай. Още не сме претърсили всички останки.")

dialogId("mot-m-akce0", "font_small", "I am sorry that none of these technical marvels around us work.")
dialogStr("Съжалявам, че никое от тези технически чудеса около нас не работи.")

dialogId("mot-m-akce1", "font_small", "I’d like to see some of these extraterrestrial gizmos in action.")
dialogStr("Бих искала да видя някоя от тези извънземни джаджи в действие.")

dialogId("mot-m-akce2", "font_small", "I wonder if this motor could work under water.")
dialogStr("Чудя се дали този двигател може да работи под вода?")

dialogId("mot-v-funkce0", "font_big", "Maybe it’s better for us if it doesn’t work.")
dialogStr("За нас може би е по-добре ако не работи.")

dialogId("mot-v-funkce1", "font_big", "I am rather glad we cannot turn anything on here.")
dialogStr("Аз пък се радвам, че не можем да включим нищо.")

dialogId("mot-v-funkce2", "font_big", "We should be happy that we could not switch anything on yet.")
dialogStr("Би трябвало да сме доволни, че все още не можем да включим нищо.")

dialogId("mot-v-klic", "font_big", "Careful with that wrench.")
dialogStr("Внимавай с този гаечен ключ.")

dialogId("mot-m-ublizit", "font_small", "I can’t harm anything here.")
dialogStr("Едва ли ще повредя нищо.")

dialogId("mot-m-zvuky0", "font_small", "What have you done? Turn off that roar!")
dialogStr("Какво направи? Изключи този рев!")

dialogId("mot-m-zvuky1", "font_small", "This is terrible! Turn it off before it’s too late!")
dialogStr("Това е ужасно! Изключи го преди да е станало късно!")

dialogId("mot-v-nemuzu0", "font_big", "I can’t! I can’t take it out!")
dialogStr("Не мога! Не мога да го извадя!")

dialogId("mot-v-nemuzu1", "font_big", "I don’t know how! I can’t take it out!")
dialogStr("Не знам как! Не мога да го извадя!")

dialogId("mot-m-mayday", "font_small", "Mayday! Mayday!")
dialogStr("Помощ! Помощ!")

dialogId("mot-v-konecne0", "font_big", "Finally.")
dialogStr("Най-сетне.")

dialogId("mot-v-konecne1", "font_big", "What a relief.")
dialogStr("Какво облекчение.")

dialogId("mot-v-zvuky0", "font_big", "What are you doing? Where are we going?")
dialogStr("Какво правиш? Къде отиваш?")

dialogId("mot-v-zvuky1", "font_big", "What have you activated? Where is it taking us?")
dialogStr("Какво включи? Къде ни води?")

dialogId("mot-m-nemuzu0", "font_small", "How can I turn it off?!")
dialogStr("Как да го изключа?!")

dialogId("mot-m-nemuzu1", "font_small", "I can’t turn it off!")
dialogStr("Не мога да го изключа!")

dialogId("mot-m-konecne0", "font_small", "Thanks.")
dialogStr("Благодаря.")

dialogId("mot-m-konecne1", "font_small", "Finally.")
dialogStr("Най-сетне.")

dialogId("mot-v-znovu0", "font_big", "I am only afraid we’ll have to turn it on again.")
dialogStr("Безпокоя се само, че ще се наложи пак да го включим.")

dialogId("mot-x-motor", "", "")
dialogStr("")
